e_vs_r: Compare Exact Bootstrap vs Regular Bootstrap
Description
This function runs the exact and regular bootstrap functions on
a dataset, summarizes the results, and provides a comparative plot. It provides
a convenient way to compare these two methods of bootstrapping.