Learn R Programming

exactamente (version 0.1.1)

exactamente_app: exactamente_app: Interactive Shiny App for Exploring Bootstrap Methods

Description

Launches a Shiny app to interactively explore and compare Exact and Regular bootstrap methods and All. The app provides a user-friendly interface, allowing users to modify various parameters associated with each bootstrap method, visualize the results, and understand the differences between the methods.

Usage

exactamente_app()

Arguments

Value

A shinyApp object representing the running Shiny application. This function is primarily called for its side effects, which include the launching and running of the Shiny app.

Examples

Run this code
if(interactive()){
  exactamente_app()
}

Run the code above in your browser using DataLab