Launches a Shiny app to interactively explore and compare Exact and Regular
bootstrap methods and All. The app provides a user-friendly interface, allowing
users to modify various parameters associated with each bootstrap method,
visualize the results, and understand the differences between the methods.